@@ -1,4 +1,3 @@
-import logging
 import warnings
 from collections import namedtuple
 from datetime import datetime
@@ -9,12 +8,13 @@ from aiohttp import ClientSession, ClientResponse, ContentTypeError
 from async_timeout import timeout
 
 from ..config import get_client_id, get_oauth, DEFAULT_CLIENT_ID
-from ..data import UserFollowers, UserInfo, RateLimit
+from ..data import UserFollowers, UserInfo, Follower
 
 __all__ = ('CHANNEL_CHATTERS_URL', 'get_channel_chatters', 'get_stream_data', 'get_url', 'get_user_data', 'get_user_id',
            'STREAM_API_URL', 'USER_API_URL', 'get_user_followers', 'USER_FOLLOWERS_API_URL', 'get_headers',
-           'get_user_info', 'get_user_creation_date', 'USER_ACCOUNT_AGE_API', 'CHANNEL_INFO_API', 'get_channel_info', 'ChannelInfo',
-           'get_channel_name_from_user_id', 'OauthTokenInfo', 'get_oauth_token_info', '_check_token', 'post_url')
+           'get_user_info', 'USER_ACCOUNT_AGE_API', 'CHANNEL_INFO_API', 'get_channel_info', 'ChannelInfo',
+           'get_channel_name_from_user_id', 'OauthTokenInfo', 'get_oauth_token_info', '_check_token', 'post_url', 'USER_FOLLOWAGE_API_URL',
+           'get_user_followage')
 
 USER_API_URL = 'https://api.twitch.tv/helix/users?login={}'
 STREAM_API_URL = 'https://api.twitch.tv/helix/streams?user_login={}'
@@ -22,6 +22,7 @@ CHANNEL_CHATTERS_URL = 'https://tmi.twitch.tv/group/user/{}/chatters'
 USER_FOLLOWERS_API_URL = 'https://api.twitch.tv/helix/users/follows?to_id={}'
 USER_ACCOUNT_AGE_API = 'https://api.twitch.tv/kraken/users/{}'
 CHANNEL_INFO_API = 'https://api.twitch.tv/helix/channels?broadcaster_id={}'
+USER_FOLLOWAGE_API_URL = 'https://api.twitch.tv/helix/users/follows?to_id={}&from_id={}'
 
 user_id_cache: Dict[str, int] = {}
 
@@ -78,19 +79,6 @@ async def get_user_info(user: str) -> UserInfo:
     )
 
 
-async def get_user_creation_date(user: str) -> datetime:
-    headers = get_headers(use_kraken=True)
-    if not _check_headers_has_auth(headers):
-        warnings.warn('[GET_USER_CREATION_DATE] headers for the twitch api request are missing authorization')
-        return datetime.min()
-
-    _, json = await get_url(USER_ACCOUNT_AGE_API.format(user), headers)
-    if 'created_at' not in json:
-        return datetime.min()
-    #                                            2012-09-03T01:30:56Z
-    return datetime.strptime(json['created_at'], '%Y-%m-%dT%H:%M:%SZ')
-
-
 async def get_user_followers(user: str, headers: dict = None) -> UserFollowers:
     headers = headers if headers is not None else get_headers()
     if not _check_headers_has_auth(headers):
@@ -99,7 +87,6 @@ async def get_user_followers(user: str, headers: dict = None) -> UserFollowers:
 
     user_id = await get_user_id(user, headers)
     _, json = await get_url(USER_FOLLOWERS_API_URL.format(user_id), headers)
-    # ratelimit = RateLimit.from_headers(_.headers)
 
     # covers invalid user id, or some other API error, such as invalid client-id
     if not json or json.get('status', -1) == 400:
@@ -113,6 +100,29 @@ async def get_user_followers(user: str, headers: dict = None) -> UserFollowers:
                          followers=json['data'])
 
 
+async def get_user_followage(channel_name: str, follower: str, headers: dict = None) -> Follower:
+    headers = headers if headers is not None else get_headers()
+    if not _check_headers_has_auth(headers):
+        warnings.warn('[GET_USER_FOLLOWAGE] headers for the twitch api request are missing authorization')
+        return Follower(-1, '', -1, '', datetime.min)
+
+    channel_id = await get_user_id(channel_name, headers)
+    follower_id = await get_user_id(follower, headers)
+    _, json = await get_url(USER_FOLLOWAGE_API_URL.format(follower_id, channel_id), headers)
+
+    # verify that the api response has data, and its total is not 0
+    if not json or not json.get('total', 0) or not json.get('data'):
+        return Follower(-1, '', -1, '', datetime.min)
+
+    # todo: test this out properly
+    return Follower(following=channel_name,
+                    following_id=channel_id,
+                    id=follower_id,
+                    name=json['data'][0]['from_name'],
+                    # datetime format: 2019-10-23T23:12:06Z
+                    followed_at=datetime.fromisoformat(json['data'][0]['followed_at'][:-1]))
+
+
 async def get_user_data(user: str, headers: dict = None) -> dict:
     headers = headers if headers is not None else get_headers()
     if not _check_headers_has_auth(headers):
